## $Id: export.py 13544 2015-12-16 06:07:20Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Exporters for applicant-related stuff.
"""
import grok
from waeup.kofa.applicants.interfaces import IApplicantBaseData
from waeup.kofa.applicants.export import ApplicantPaymentExporter
from waeup.kofa.utils.helpers import iface_names
from kofacustom.nigeria.applicants.export import NigeriaApplicantExporter
from kofacustom.nigeria.applicants.interfaces import (
    INigeriaUGApplicant, INigeriaPGApplicant, IBankAccount)
from waeup.uniben.applicants.interfaces import (
    IUnibenRegistration, ITranscriptApplicant)

class CustomApplicantExporter(NigeriaApplicantExporter):
    """Exporter for Nigeria Applicants.
    """

    fields = tuple(sorted(set(
        iface_names(INigeriaUGApplicant) +
        iface_names(INigeriaPGApplicant) +
        iface_names(IApplicantBaseData) +
        iface_names(IUnibenRegistration) +
        iface_names(ITranscriptApplicant) +
        iface_names(IBankAccount)
        ))) + (
        'password', 'state', 'history', 'container_code', 'application_number',
        'display_fullname', 'application_date')

class CustomApplicantPaymentExporter(ApplicantPaymentExporter):
    """Exporter for OnlinePayment instances.
    """

    @property
    def fields(self):
        return super(CustomApplicantPaymentExporter, self).fields + (
            'r_pay_reference',)

class PGApplicantExporter(NigeriaApplicantExporter):
    """Exports pg applicants only.
    """

    grok.name('pg_applicants')
    title = 'PG Applicants'

    def is_postgrad(self, applicant):
        course_studied = getattr(applicant, 'course_studied', None)
        if course_studied is not None and (
              course_studied.study_mode.startswith('pg')
              or course_studied.study_mode.startswith('special_pg')):
            return True
        return False

    def export(self, applicants, filepath=None):
        """
        """
        writer, outfile = self.get_csv_writer(filepath)
        for applicant in applicants:
            if self.is_postgrad(applicant):
                self.write_item(applicant, writer)
        return self.close_outfile(filepath, outfile)
